v1alpha1

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type M3DBClusterLister

type M3DBClusterLister interface {
	// List lists all M3DBClusters in the indexer.
	List(selector labels.Selector) (ret []*v1alpha1.M3DBCluster, err error)
	// M3DBClusters returns an object that can list and get M3DBClusters.
	M3DBClusters(namespace string) M3DBClusterNamespaceLister
	M3DBClusterListerExpansion
}

M3DBClusterLister helps list M3DBClusters.

func NewM3DBClusterLister

func NewM3DBClusterLister(indexer cache.Indexer) M3DBClusterLister

NewM3DBClusterLister returns a new M3DBClusterLister.

type M3DBClusterListerExpansion

type M3DBClusterListerExpansion interface{}

M3DBClusterListerExpansion allows custom methods to be added to M3DBClusterLister.

type M3DBClusterNamespaceLister

type M3DBClusterNamespaceLister interface {
	// List lists all M3DBClusters in the indexer for a given namespace.
	List(selector labels.Selector) (ret []*v1alpha1.M3DBCluster, err error)
	// Get retrieves the M3DBCluster from the indexer for a given namespace and name.
	Get(name string) (*v1alpha1.M3DBCluster, error)
	M3DBClusterNamespaceListerExpansion
}

M3DBClusterNamespaceLister helps list and get M3DBClusters.

type M3DBClusterNamespaceListerExpansion

type M3DBClusterNamespaceListerExpansion interface{}

M3DBClusterNamespaceListerExpansion allows custom methods to be added to M3DBClusterNamespaceLister.

Jump to